@@ -134,12 +134,12 @@ var _ = Describe("Watch Factory Operations", func() {
 		policies                                  []*knet.NetworkPolicy
 		endpoints                                 []*v1.Endpoints
 		services                                  []*v1.Service
-		stop                                      chan struct{}
+		wf                                        *WatchFactory
+		err                                       error
 	)
 
 	BeforeEach(func() {
 		fakeClient = &fake.Clientset{}
-		stop = make(chan struct{})
 
 		pods = make([]*v1.Pod, 0)
 		podWatch = objSetup(fakeClient, "pods", func(core.Action) (bool, runtime.Object, error) {
@@ -197,12 +197,12 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	AfterEach(func() {
-		close(stop)
+		wf.Shutdown()
 	})
 
 	Context("when a processExisting is given", func() {
 		testExisting := func(objType reflect.Type, namespace string, lsel *metav1.LabelSelector) {
-			wf, err := NewWatchFactory(fakeClient, stop)
+			wf, err = NewWatchFactory(fakeClient)
 			Expect(err).NotTo(HaveOccurred())
 			h, err := wf.addHandler(objType, namespace, lsel,
 				cache.ResourceEventHandlerFuncs{},
@@ -257,7 +257,7 @@ var _ = Describe("Watch Factory Operations", func() {
 
 	Context("when existing items are known to the informer", func() {
 		testExisting := func(objType reflect.Type) {
-			wf, err := NewWatchFactory(fakeClient, stop)
+			wf, err = NewWatchFactory(fakeClient)
 			Expect(err).NotTo(HaveOccurred())
 			var addCalls int32
 			h, err := wf.addHandler(objType, "", nil,
@@ -339,7 +339,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	}
 
 	It("responds to pod add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newPod("pod1", "default")
@@ -373,7 +373,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to multiple pod add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		const nodeName string = "mynode"
@@ -443,7 +443,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to namespace add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newNamespace("default")
@@ -477,7 +477,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to node add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newNode("mynode")
@@ -511,7 +511,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to multiple node add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		type opTest struct {
@@ -595,7 +595,7 @@ var _ = Describe("Watch Factory Operations", func() {
 			nodes = append(nodes, node)
 		}
 
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		startWg := sync.WaitGroup{}
@@ -668,7 +668,7 @@ var _ = Describe("Watch Factory Operations", func() {
 			namespaces = append(namespaces, namespace)
 		}
 
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		startWg := sync.WaitGroup{}
@@ -726,7 +726,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to policy add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newPolicy("mypolicy", "default")
@@ -760,7 +760,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to endpoints add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newEndpoints("myendpoints", "default")
@@ -801,7 +801,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("responds to service add/update/delete events", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newService("myservice", "default")
@@ -835,7 +835,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("stops processing events after the handler is removed", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		added := newNamespace("default")
@@ -864,7 +864,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("filters correctly by label and namespace", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		passesFilter := newPod("pod1", "default")
@@ -928,7 +928,7 @@ var _ = Describe("Watch Factory Operations", func() {
 	})
 
 	It("correctly handles object updates that cause filter changes", func() {
-		wf, err := NewWatchFactory(fakeClient, stop)
+		wf, err = NewWatchFactory(fakeClient)
 		Expect(err).NotTo(HaveOccurred())
 
 		pod := newPod("pod1", "default")
